# pywctl
A utility to connect you, using python, to iwd, using iwctl, in ash. Made specifically for snakeware.

# Dependencies
```
python3
pip
iwd
git
```
and an internet connection (unless you're on snakeware, then it's included for MY FORK.)

# Installation
This will install the module from pypi's official repo.
```
python3 -m pip install pywctl
```
If you don't trust pypi for some reason, then do this, although pypi is much easier to use.
```
git clone https://www.github.com/SorrowEater/pywctl.git
cd pywctl
python3 -m pip install .
```
